@@ -1,4 +1,15 @@
-'''module docstring'''
+'''
+Font weight template can only be used when the text can be displayed in HTML mode.
+Such as WEB page, Blog, EMail, etc. 
+
+Note: Need to wrap surrounding elements
+    It should be noted that all text needs to be wrapped with a layer of elements in 
+    order to obtain a unified style display
+
+Warning: confusables_chars_key is needed
+    You can choose one of the key to insert the watermark
+    
+'''
 
 from textwatermark.common import add_head_n_tial_to_dict
 from textwatermark.defines import WMMethod
@@ -9,6 +20,7 @@ CONFUSABLES_CHARS_END_WITH = ';">{char}</span>'
 CONFUSABLES_CHARS = {
     'lighter': ['normal', 'lighter'],
     'bolder': ['normal', 'bolder'],
+    'lighter-bolder': ['lighter', 'bolder'],
     '100-200': ['100', '200'],
     '200-300': ['200', '300'],
     '300-400': ['300', '400'],
