@@ -1,4 +1,9 @@
-'''watermark template class of invisible chars'''
+'''Watermark template of invisible chars.
+
+All of the chars below are invisible on most of the text editors and WEB view.
+
+In most cases, using this template is a pretty good choice.
+'''
 
 from textwatermark.defines import WMMethod
 
